aboutsummaryrefslogtreecommitdiff
path: root/tofu
diff options
context:
space:
mode:
authorAdnan Maolood <[email protected]>2021-01-14 18:52:43 -0500
committerAdnan Maolood <[email protected]>2021-01-14 18:52:43 -0500
commit4a0f8e5e73f82d5f95433030422bcab2582ad150 (patch)
tree5cfecb354c753918a0b2eb65dd98c8f90af3e75d /tofu
parentAdd KnownHosts.Hosts function (diff)
downloadgo-gemini-4a0f8e5e73f82d5f95433030422bcab2582ad150.tar.xz
go-gemini-4a0f8e5e73f82d5f95433030422bcab2582ad150.zip
tofu: Rename KnownHosts.Hosts to Entries
Diffstat (limited to 'tofu')
-rw-r--r--tofu/tofu.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/tofu/tofu.go b/tofu/tofu.go
index 7c7e04a..e4bceab 100644
--- a/tofu/tofu.go
+++ b/tofu/tofu.go
@@ -46,8 +46,8 @@ func (k *KnownHosts) Lookup(hostname string) (Host, bool) {
return c, ok
}
-// Hosts returns the known hosts sorted by hostname.
-func (k *KnownHosts) Hosts() []Host {
+// Entries returns the known host entries sorted by hostname.
+func (k *KnownHosts) Entries() []Host {
keys := make([]string, 0, len(k.hosts))
for key := range k.hosts {
keys = append(keys, key)